@@ -1,5 +1,6 @@
 import string
-from simplenlp import NLTools, get_nl, get_wordlist, get_mapping
+from simplenlp import NLTools, get_nl, get_wordlist, get_mapping,\
+                      preprocess_text
 import re
 
 def doctest_globals():
@@ -94,21 +95,21 @@ class EuroNL(NLTools):
         input to do.
 
             >>> en_nl.tokenize("Time is an illusion. Lunchtime, doubly so.")
-            'Time is an illusion . Lunchtime , doubly so .'
+            u'Time is an illusion . Lunchtime , doubly so .'
             >>> untok = '''
             ... "Very deep," said Arthur, "you should send that in to the
             ... Reader's Digest. They've got a page for people like you."
             ... '''
             >>> tok = en_nl.tokenize(untok)
             >>> tok
-            "`` Very deep , '' said Arthur , `` you should send that in to the Reader 's Digest . They 've got a page for people like you . ''"
+            u"`` Very deep , '' said Arthur , `` you should send that in to the Reader 's Digest . They 've got a page for people like you . ''"
             >>> en_nl.untokenize(tok)
-            '"Very deep," said Arthur, "you should send that in to the Reader\'s Digest. They\'ve got a page for people like you."'
+            u'"Very deep," said Arthur, "you should send that in to the Reader\'s Digest. They\'ve got a page for people like you."'
             >>> en_nl.untokenize(tok) == untok.replace('\n', ' ').strip()
             True
 
         """
-        step0 = text.replace('\r', '').replace('\n', ' ')
+        step0 = preprocess_text(text).replace('\r', '').replace('\n', ' ')
         step1 = step0.replace(" '", " ` ").replace("'", " '").replace("n 't", 
         " n't").replace("cannot", "can not")
         step2 = re.sub('"([^"]*)"', r" `` \1 '' ", step1)
@@ -140,7 +141,7 @@ class EuroNL(NLTools):
 
         In a EuroNL, by default, this puts those characters in lowercase.
         """
-        return word.lower()
+        return preprocess_text(word).lower()
 
     def is_stopword(self, word):
         """
